==> haskell-base-orphans-0.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.7
id: base-orphans-0.7-2rnBC8i8xg4MGwTKD2Jdu
key: base-orphans-0.7-2rnBC8i8xg4MGwTKD2Jdu
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: b1a1a3f2178835e8693751899a3f53fd
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.2/site-local/base-orphans-0.7
library-dirs: /usr/lib/ghc-8.4.2/site-local/base-orphans-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/base-orphans-0.7
hs-libraries: HSbase-orphans-0.7-2rnBC8i8xg4MGwTKD2Jdu
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.7-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.7
id: base-orphans-0.7-DFzqJo74HQjHjfhO0xkTzo
key: base-orphans-0.7-DFzqJo74HQjHjfhO0xkTzo
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: 9502af04c7c3772a92a8cf1ef282323a
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-orphans-0.7
hs-libraries: HSbase-orphans-0.7-DFzqJo74HQjHjfhO0xkTzo
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
